netapp_ontap.models.nvme_subsystem_controller_interface API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.nvme_subsystem_controller_interface`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class NvmeSubsystemControllerInterfaceSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NvmeSubsystemControllerInterface object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `name GET`

    The name of the logical interface.

    Example: lif1

  `transport_address GET`

    The transport address of the logical interface.

    Example: nn-0x200400a0989a1c8d:pn-0x200500a0989a1c8d

  `uuid GET`

    The unique identifier of the logical interface.

    Example: fa1c5941-2593-11e9-94c4-00a0989a1c8e